@@ -1,8 +1,8 @@
-from ..MetaDataObject import MetaDataObject
+from ..MetaDataObject.core.Simple import SimpleNameFolder
 from ..MetaDataObject.versions.DocumentForm803 import DocumentForm803
 
 
-class CatalogForm(MetaDataObject):
+class CatalogForm(SimpleNameFolder):
     versions = {
         '803': DocumentForm803
     }
