@@ -1,5 +1,5 @@
-import json
 import copy
+import json
 import os
 import shutil
 import time
@@ -243,6 +243,7 @@ def get_near_descent_file_name(path, file_name, descent):
     startswith = '.'.join(name[0:-1])
     endswith = name[-1]
     size = len(name)
+    is_without_descent = False
     try:
         entities = os.listdir(path)
     except FileNotFoundError:
@@ -253,6 +254,7 @@ def get_near_descent_file_name(path, file_name, descent):
         if entity.startswith(startswith) and entity.endswith(endswith):
             _entity = entity.split('.')
             if len(_entity) - 1 != size:
+                is_without_descent = True
                 continue
             full_path = os.path.join(path, entity)
             if os.path.isfile(full_path):
@@ -261,9 +263,13 @@ def get_near_descent_file_name(path, file_name, descent):
                 except ValueError:  # если во втором разряде не число, значит не наш вариант
                     pass
     if not descents:
+        if is_without_descent:
+            return path, file_name
         return '', ''
     descents = sorted(descents, reverse=True, key=lambda x: 0 if x > descent else x)
     if descents[0] > descent:
+        if is_without_descent:
+            return path, file_name
         return '', ''
     return path, f'{startswith}.{descents[0]}.{endswith}'
 
@@ -304,6 +310,7 @@ def update_dict(*args):
             result = _update_dict(result, args[i + 1])
         return result
 
+
 def _update_dict(base, new, _path=''):
     if not new:
         return base
@@ -345,4 +352,31 @@ def _update_dict(base, new, _path=''):
                     'element': element,
                     'message': str(err)
                 })
-    return base
\ No newline at end of file
+    return base
+
+
+def load_json(filename):
+    try:
+        with open(filename, 'r', encoding='utf-8') as f:
+            data = json.load(f)
+        if not isinstance(data, dict):
+            raise Exception(f'Index file not dict ({filename})\n')
+        return data
+    except FileNotFoundError:
+        raise Exception(f'Index file not found ({filename})')
+    except Exception as err:
+        raise Exception(f'Bad index file ({filename}) - {err}\n')
+
+
+def check_index(index_filename):
+    if index_filename:
+        index = []
+        _index = load_json(index_filename)
+        sub_index = _index.pop('index.json', None)
+        if sub_index:
+            for elem in sub_index:
+                index.append(load_json(elem))
+        index.append(_index)
+        data = update_dict(*index)
+        return data
+    return None
